Condition

Enum Condition 

pub enum Condition {
Show 14 variants True, False, Not(Box<Condition>), And(Box<Condition>, Box<Condition>), Or(Box<Condition>, Box<Condition>), ConnectionSeqNo(usize), RequestOpcode(RequestOpcode), ResponseOpcode(ResponseOpcode), BodyContainsCaseSensitive(Box<[u8]>), BodyContainsCaseInsensitive(Box<[u8]>), RandomWithProbability(f64), TrueForLimitedTimes(usize), ConnectionRegisteredAnyEvent, RequestConsistency(Consistency, ProtocolFeatures),
}
Specifies when an associated Reaction will be performed. Conditions are subject to logic, with not(), and() and or() convenience functions.

Variants



True



False



Not(Box<Condition>)



And(Box<Condition>, Box<Condition>)



Or(Box<Condition>, Box<Condition>)



ConnectionSeqNo(usize)

True iff the frame has come in the n-th driver connection established with the driver.



RequestOpcode(RequestOpcode)

True iff the frame has the given opcode (and is a request).



ResponseOpcode(ResponseOpcode)

True iff the frame has the given opcode (and is a response).



BodyContainsCaseSensitive(Box<[u8]>)

True iff the frame body contains the given byte slice, with case-sensitive comparison.



BodyContainsCaseInsensitive(Box<[u8]>)

True iff the frame body contains the given byte slice, with case-insensitive comparison (ASCII only).



RandomWithProbability(f64)

True with the given probability.



TrueForLimitedTimes(usize)

True for predefined number of evaluations, then always false.



ConnectionRegisteredAnyEvent

True if any REGISTER was sent on this connection. Useful to filter out control connection messages.



RequestConsistency(Consistency, ProtocolFeatures)

True iff the request frame has the given consistency level. Only applicable to request frames (Query, Execute, Batch). Returns false for response frames or requests that cannot be deserialized. The provided ProtocolFeatures must match the features negotiated between the driver and the server for correct deserialization of the frame.

Implementations

Source

impl Condition

pub fn not(c: Self) -> Self

A convenience function for creating Condition::Not variant.

pub fn and(self, c2: Self) -> Self

A convenience function for creating Condition::And variant.

pub fn or(self, c2: Self) -> Self

A convenience function for creating Condition::Or variant.

pub fn all(cs: impl IntoIterator<Item = Self>) -> Self

A convenience function for creating a tree with Condition::And variant in nodes.

pub fn any(cs: impl IntoIterator<Item = Self>) -> Self

A convenience function for creating a tree with Condition::Or variant in nodes.