pub struct Node { /* private fields */ }Implementations
Sourceimpl Node
impl Node
Sourcepub fn new(
real_addr: SocketAddr,
proxy_addr: SocketAddr,
shard_awareness: ShardAwareness,
request_rules: Option<Vec<RequestRule>>,
response_rules: Option<Vec<ResponseRule>>,
) -> Self
pub fn new( real_addr: SocketAddr, proxy_addr: SocketAddr, shard_awareness: ShardAwareness, request_rules: Option<Vec<RequestRule>>, response_rules: Option<Vec<ResponseRule>>, ) -> Self
Creates an abstract node that is backed by a real Scylla node.
Sourcepub fn new_dry_mode(
proxy_addr: SocketAddr,
request_rules: Option<Vec<RequestRule>>,
) -> Self
pub fn new_dry_mode( proxy_addr: SocketAddr, request_rules: Option<Vec<RequestRule>>, ) -> Self
Creates a simulated node that is not backed by any real Scylla node.
pub fn builder() -> NodeBuilder