pub struct RequestRule(pub Condition, pub RequestReaction);Expand description
A rule describing what actions should the proxy perform with the received request frame and on what conditions.
Tuple Fields
0: Condition1: RequestReactionTrait Implementations
Sourceimpl Clone for RequestRule
impl Clone for RequestRule
Sourcefn clone(&self) -> RequestRule
fn clone(&self) -> RequestRule
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for RequestRule
impl !RefUnwindSafe for RequestRule
impl Send for RequestRule
impl Sync for RequestRule
impl Unpin for RequestRule
impl UnsafeUnpin for RequestRule
impl !UnwindSafe for RequestRule