pub struct ResponseFrame {
pub params: FrameParams,
pub opcode: ResponseOpcode,
pub body: Bytes,
pub wire_body_len: usize,
}Fields
params: FrameParamsopcode: ResponseOpcodebody: BytesThe frame body, decompressed if the frame arrived compressed.
wire_body_len: usizeNumber of body bytes as they appeared on the wire, i.e. before decompression.
For frames that were not compressed this is equal to body.len().
See RequestFrame::wire_body_len for the rationale.
Implementations
Sourceimpl ResponseFrame
impl ResponseFrame
Sourcepub fn new(params: FrameParams, opcode: ResponseOpcode, body: Bytes) -> Self
pub fn new(params: FrameParams, opcode: ResponseOpcode, body: Bytes) -> Self
Creates a frame whose body did not undergo compression, so that its
Self::wire_body_len is simply the body length.
Sourcepub fn forged_error(
request_params: FrameParams,
error: DbError,
msg: Option<&str>,
) -> Result<Self, TryFromIntError>
pub fn forged_error( request_params: FrameParams, error: DbError, msg: Option<&str>, ) -> Result<Self, TryFromIntError>
Creates a response frame that signifies the given DbError type. Useful for testing server-side error handling in drivers.
Sourcepub fn forged_supported(
request_params: FrameParams,
options: &HashMap<String, Vec<String>>,
) -> Result<Self, TryFromIntError>
pub fn forged_supported( request_params: FrameParams, options: &HashMap<String, Vec<String>>, ) -> Result<Self, TryFromIntError>
Creates a Supported response frame with given supported options.
pub fn forged_ready(request_params: FrameParams) -> Self