pub struct ResponseRule(pub Condition, pub ResponseReaction);Expand description
A rule describing what actions should the proxy perform with the received response frame and on what conditions.
Tuple Fields
0: Condition1: ResponseReactionTrait Implementations
Sourceimpl Clone for ResponseRule
impl Clone for ResponseRule
Sourcefn clone(&self) -> ResponseRule
fn clone(&self) -> ResponseRule
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for ResponseRule
impl !RefUnwindSafe for ResponseRule
impl Send for ResponseRule
impl Sync for ResponseRule
impl Unpin for ResponseRule
impl UnsafeUnpin for ResponseRule
impl !UnwindSafe for ResponseRule