pub struct ResponseFrame {
pub params: FrameParams,
pub opcode: ResponseOpcode,
pub body: Bytes,
}Fields
params: FrameParamsopcode: ResponseOpcodebody: BytesImplementations
Sourceimpl ResponseFrame
impl ResponseFrame
Sourcepub fn forged_error(
request_params: FrameParams,
error: DbError,
msg: Option<&str>,
) -> Result<Self, TryFromIntError>
pub fn forged_error( request_params: FrameParams, error: DbError, msg: Option<&str>, ) -> Result<Self, TryFromIntError>
Creates a response frame that signifies the given DbError type. Useful for testing server-side error handling in drivers.
Sourcepub fn forged_supported(
request_params: FrameParams,
options: &HashMap<String, Vec<String>>,
) -> Result<Self, TryFromIntError>
pub fn forged_supported( request_params: FrameParams, options: &HashMap<String, Vec<String>>, ) -> Result<Self, TryFromIntError>
Creates a Supported response frame with given supported options.
pub fn forged_ready(request_params: FrameParams) -> Self