pub struct TransportFactory { /* private fields */ }Expand description
Creates DuplexStreams that directly connect to the associated proxy’s
nodes.
This is an alternative method of establishing a transport layer connection to the proxy nodes. The purpose of this alternative method is to allow writing tests that use tokio’s paused time feature. The advantage of using a channel is that, when some data is sent on the channel, the waiting task will be immediately notified and scheduled for execution. For system sockets this is not guaranteed and the receiving task may be notified after a real-time delay, which can trick tokio’s timer auto-advance and make it move the time forward, even if the task on the receiving side would have been notified earlier in a real scenario.
Implementations
Sourceimpl TransportFactory
impl TransportFactory
pub fn connect( &self, connect_address: SocketAddr, source_ip: Option<IpAddr>, source_port: Option<u16>, ) -> Result<DuplexStream, Error>